==> MacPacbot-1.0.0.tar.gz: MacPacbot-1.0.0/setup.py <==
#!/usr/bin/env python
# -*- encoding: utf-8 -*-

from setuptools import setup

setup(
    name = 'MacPacbot',
    version = '1.0.0',
    author = 'dexteryy',
    author_email = 'dexter.yy@gmail.com',
    url = 'https://dexteryy.github.com/MacPacbot',
    description = 'MacPacbot is a Python toolkit for PAC(auto proxy configuration) of Mac OS X',
    entry_points = {
        "console_scripts": ['pacbot = pacbot:main']
    },
    #packages = ['macpacbot'],
    keywords = ["PAC", "proxy", "mac", "GFW"],
    classifiers = [
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Development Status :: 4 - Beta",
        "Environment :: MacOS X",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: MacOS :: MacOS X",
        "Topic :: System :: Systems Administration"
    ],
    long_description = """\
MacPacbot is a Python toolkit for PAC(auto proxy configuration) of Mac OS X, which makes it much easier to create, edit and enable PAC script.
It could transform a simple YAML config into a valid PAC script. 

## Usage

Transform YAML info PAC:
    pacbot <yaml_file> -o <pac_file>

Automatically detect network-service and update auto proxy configuration:
    pacbot -u [-o <pac_file>]

Disable auto proxy in current network-service:
    pacbot -s off

Vim plugin:
    function! EnablePAC()
        if &filetype == 'javascript'
            !sudo pacbot -u -o %
        elseif &filetype == 'yaml'
            !sudo pacbot %
        endif
    endfunction

    command! PACenable call EnablePAC() 
    autocmd! bufwritepost *.pac :PACenable
    autocmd! bufwritepost *.ypac :PACenable
"""
)

==> MacPacbot-1.0.1.tar.gz: MacPacbot-1.0.1/setup.py <==
#!/usr/bin/env python
# -*- encoding: utf-8 -*-

from setuptools import setup

setup(
    name = 'MacPacbot',
    version = '1.0.1',
    author = 'dexteryy',
    author_email = 'dexter.yy@gmail.com',
    url = 'https://dexteryy.github.com/MacPacbot',
    description = 'MacPacbot is a Python toolkit for PAC(auto proxy configuration) of Mac OS X',
    entry_points = {
        "console_scripts": ['pacbot = MacPacbot:main']
    },
    #packages = ['macpacbot'],
    keywords = ["PAC", "proxy", "mac", "GFW"],
    classifiers = [
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Development Status :: 4 - Beta",
        "Environment :: MacOS X",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: MacOS :: MacOS X",
        "Topic :: System :: Systems Administration"
    ],
    long_description = """\
MacPacbot is a Python toolkit for PAC(auto proxy configuration) of Mac OS X, which makes it much easier to create, edit and enable PAC script.
It could transform a simple YAML config into a valid PAC script. 

## Usage

Transform YAML info PAC:
    pacbot <yaml_file> -o <pac_file>

Automatically detect network-service and update auto proxy configuration:
    pacbot -u [-o <pac_file>]

Disable auto proxy in current network-service:
    pacbot -s off

Vim plugin:
    function! EnablePAC()
        if &filetype == 'javascript'
            !sudo pacbot -u -o %
        elseif &filetype == 'yaml'
            !sudo pacbot %
        endif
    endfunction

    command! PACenable call EnablePAC() 
    autocmd! bufwritepost *.pac :PACenable
    autocmd! bufwritepost *.ypac :PACenable
"""
)
